;;; custom-load.el --- automatically extracted custom dependencies

;;; Code:

(autoload 'custom-add-loads "cus-load")

(custom-add-loads 'extensions '("sha1"))
(custom-add-loads 'password '("password"))
(custom-add-loads 'rijndael '("rijndael"))
(custom-add-loads 'encrypt '("password" "encrypt"))
(custom-add-loads 'applications '("encrypt"))
(custom-add-loads 'sha1 '("sha1"))

;;; custom-load.el ends here
